@@ -18,15 +18,15 @@ my $plot = IUP::PPlot->new(
 	     AXS_YAUTOMAX => "NO",
 );
 
-$plot->PlotBegin(2);
+$plot->PlotBegin(0);
 for (my $x=-2; $x<=2; $x+=0.01) {
-  $plot->PlotAdd2D($x, sin($x))
+  $plot->PlotAdd($x, sin($x))
 }
 $plot->PlotEnd();
 
-$plot->PlotBegin(2);
+$plot->PlotBegin(0);
 for (my $x=-2; $x<=2; $x+=0.01) {
-  $plot->PlotAdd2D($x, cos($x))
+  $plot->PlotAdd($x, cos($x))
 }
 $plot->PlotEnd();
 
