@@ -31,7 +31,5 @@ package IUP::Canvas::Bitmap;
 package IUP::Canvas::Palette;
 package IUP::Canvas::Pattern;
 package IUP::Canvas::Stipple;
-package IUP::Canvas::InternalServerImage;
-package IUP::Canvas::InternalState;
 
 1;
